@@ -149,7 +149,7 @@ function traiter_appels_inclusions_ajax() {
 			}
 		} else {
 			include_spip('inc/headers');
-			http_status(403);
+			http_status(400);
 			$texte = _L('signature ajax bloc incorrecte');
 		}
 		ajax_retour($texte, false);
@@ -183,9 +183,30 @@ function traiter_formulaires_dynamiques($get = false) {
 		return false;
 	} // le hit peut continuer normalement
 
+	// verifier que le post est licite (du meme auteur ou d'une session anonyme)
+	$sign = _request('formulaire_action_sign');
+	if (!empty($GLOBALS['visiteur_session']['id_auteur'])) {
+		if (empty($sign)) {
+			spip_log("signature ajax form incorrecte : $form (formulaire non signe mais on a une session)", 'formulaires' . _LOG_ERREUR);
+			return false;
+		}
+		$securiser_action = charger_fonction('securiser_action', 'inc');
+		$secu = $securiser_action($form, $args, '', -1);
+		if ($sign !== $secu['hash']) {
+			spip_log("signature ajax form incorrecte : $form (formulaire signe mais ne correspond pas a la session)", 'formulaires' . _LOG_ERREUR);
+			return false;
+		}
+	}
+	else {
+		if (!empty($sign)) {
+			spip_log("signature ajax form incorrecte : $form (formulaire signe mais pas de session)", 'formulaires' . _LOG_ERREUR);
+			return false;
+		}
+	}
+
 	include_spip('inc/filtres');
 	if (($args = decoder_contexte_ajax($args, $form)) === false) {
-		spip_log("signature ajax form incorrecte : $form");
+		spip_log("signature ajax form incorrecte : $form (encodage corrompu)", 'formulaires' . _LOG_ERREUR);
 
 		return false; // continuons le hit comme si de rien etait
 	} else {
