@@ -2515,9 +2515,9 @@ function _sqlite_ref_fonctions() {
 
 
 /**
- * $query est une requete ou une liste de champs
+ * Adapte les déclarations des champs pour SQLite
  *
- * @param  $query
+ * @param string|array $query Déclaration d’un champ ou  liste de déclarations de champs
  * @param bool $autoinc
  * @return mixed
  */
@@ -2531,6 +2531,7 @@ function _sqlite_remplacements_definitions_table($query, $autoinc = false) {
 		'/COLLATE \w+_bin/is' => 'COLLATE BINARY',
 		'/COLLATE \w+_ci/is' => 'COLLATE NOCASE',
 		'/auto_increment/is' => '',
+		'/current_timestamp\(\)/is' => 'CURRENT_TIMESTAMP', // Fix export depuis mariaDB #4374
 		'/(timestamp .* )ON .*$/is' => '\\1',
 		'/character set \w+/is' => '',
 		'/((big|small|medium|tiny)?int(eger)?)' . $num . '\s*unsigned/is' => '\\1 UNSIGNED',
